/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  char c;
  char *optString = "hvf:a:";

  args = (Args *)emalloc(sizeof(Args));
  args->f = " ";
  args->a = NULL;
  args->h = 0;
  args->v = 0;
  args->e = 1;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'f':                           /* field separator */
      args->f = optarg;
      if(strcmp(args->f,"\\t") == 0)
	args->f[0] = '\t';
      break;
    case 'a':                           /* file containing amino acid background frequencies */
      args->a = optarg;
      args->e = 0;
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  return args;
}


void printUsage(char *version){
  printf("Usage: %s[options] [inputFiles]\n",progname());
  printf("Normalize entries in PAM matrix\n");
  printf("pamNormalize -a aa.txt pam70.txt\n");
  printf("Options:\n");
  printf("\t-a <FILE> containing background frequencies of amino acids\n");
  printf("\t[-f <CHAR> use field separator CHAR; default: CHAR=' ' (blank)]\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
